The pdytools Module — pyqtdeploy v2.5.1 User Guide

# The `pdytools` Module

Every deployed application is able to import the `pdytools` module. This enables the application to determine if it is running as a deployed application and, if necessary, to change its behaviour accordingly.

`pdytools.` `hexversion`

  This is the version number of pdytools encoded as a single (non-zero) integer. The encoding used is the same as that used by `sys.hexversion`.

Deployed applications also follow the convention of other deployment tools of defining an attribute called `frozen` in the `sys` module.